from __future__ import annotations

# Generated code.
# DO NOT EDIT.
# LSP v3.17.0
from enum import StrEnum


class Request(StrEnum):
    """LSP request method identifiers"""

    CALL_HIERARCHY_INCOMING_CALLS = "callHierarchy/incomingCalls"
    CALL_HIERARCHY_OUTGOING_CALLS = "callHierarchy/outgoingCalls"
    CODE_ACTION_RESOLVE = "codeAction/resolve"
    CODE_LENS_RESOLVE = "codeLens/resolve"
    COMPLETION_ITEM_RESOLVE = "completionItem/resolve"
    DOCUMENT_LINK_RESOLVE = "documentLink/resolve"
    INITIALIZE = "initialize"
    INLAY_HINT_RESOLVE = "inlayHint/resolve"
    SHUTDOWN = "shutdown"
    TEXT_DOCUMENT_CODE_ACTION = "textDocument/codeAction"
    TEXT_DOCUMENT_CODE_LENS = "textDocument/codeLens"
    TEXT_DOCUMENT_COLOR_PRESENTATION = "textDocument/colorPresentation"
    TEXT_DOCUMENT_COMPLETION = "textDocument/completion"
    TEXT_DOCUMENT_DECLARATION = "textDocument/declaration"
    TEXT_DOCUMENT_DEFINITION = "textDocument/definition"
    TEXT_DOCUMENT_DIAGNOSTIC = "textDocument/diagnostic"
    TEXT_DOCUMENT_DOCUMENT_COLOR = "textDocument/documentColor"
    TEXT_DOCUMENT_DOCUMENT_HIGHLIGHT = "textDocument/documentHighlight"
    TEXT_DOCUMENT_DOCUMENT_LINK = "textDocument/documentLink"
    TEXT_DOCUMENT_DOCUMENT_SYMBOL = "textDocument/documentSymbol"
    TEXT_DOCUMENT_FOLDING_RANGE = "textDocument/foldingRange"
    TEXT_DOCUMENT_FORMATTING = "textDocument/formatting"
    TEXT_DOCUMENT_HOVER = "textDocument/hover"
    TEXT_DOCUMENT_IMPLEMENTATION = "textDocument/implementation"
    TEXT_DOCUMENT_INLAY_HINT = "textDocument/inlayHint"
    TEXT_DOCUMENT_INLINE_COMPLETION = "textDocument/inlineCompletion"
    TEXT_DOCUMENT_INLINE_VALUE = "textDocument/inlineValue"
    TEXT_DOCUMENT_LINKED_EDITING_RANGE = "textDocument/linkedEditingRange"
    TEXT_DOCUMENT_MONIKER = "textDocument/moniker"
    TEXT_DOCUMENT_ON_TYPE_FORMATTING = "textDocument/onTypeFormatting"
    TEXT_DOCUMENT_PREPARE_CALL_HIERARCHY = "textDocument/prepareCallHierarchy"
    TEXT_DOCUMENT_PREPARE_RENAME = "textDocument/prepareRename"
    TEXT_DOCUMENT_PREPARE_TYPE_HIERARCHY = "textDocument/prepareTypeHierarchy"
    TEXT_DOCUMENT_RANGES_FORMATTING = "textDocument/rangesFormatting"
    TEXT_DOCUMENT_RANGE_FORMATTING = "textDocument/rangeFormatting"
    TEXT_DOCUMENT_REFERENCES = "textDocument/references"
    TEXT_DOCUMENT_RENAME = "textDocument/rename"
    TEXT_DOCUMENT_SELECTION_RANGE = "textDocument/selectionRange"
    TEXT_DOCUMENT_SEMANTIC_TOKENS_FULL = "textDocument/semanticTokens/full"
    TEXT_DOCUMENT_SEMANTIC_TOKENS_FULL_DELTA = "textDocument/semanticTokens/full/delta"
    TEXT_DOCUMENT_SEMANTIC_TOKENS_RANGE = "textDocument/semanticTokens/range"
    TEXT_DOCUMENT_SIGNATURE_HELP = "textDocument/signatureHelp"
    TEXT_DOCUMENT_TYPE_DEFINITION = "textDocument/typeDefinition"
    TEXT_DOCUMENT_WILL_SAVE_WAIT_UNTIL = "textDocument/willSaveWaitUntil"
    TYPE_HIERARCHY_SUBTYPES = "typeHierarchy/subtypes"
    TYPE_HIERARCHY_SUPERTYPES = "typeHierarchy/supertypes"
    WORKSPACE_DIAGNOSTIC = "workspace/diagnostic"
    WORKSPACE_EXECUTE_COMMAND = "workspace/executeCommand"
    WORKSPACE_SYMBOL = "workspace/symbol"
    WORKSPACE_SYMBOL_RESOLVE = "workspaceSymbol/resolve"
    WORKSPACE_TEXT_DOCUMENT_CONTENT = "workspace/textDocumentContent"
    WORKSPACE_WILL_CREATE_FILES = "workspace/willCreateFiles"
    WORKSPACE_WILL_DELETE_FILES = "workspace/willDeleteFiles"
    WORKSPACE_WILL_RENAME_FILES = "workspace/willRenameFiles"


class Notification(StrEnum):
    """LSP notification method identifiers"""

    CANCEL_REQUEST = "$/cancelRequest"
    EXIT = "exit"
    INITIALIZED = "initialized"
    NOTEBOOK_DOCUMENT_DID_CHANGE = "notebookDocument/didChange"
    NOTEBOOK_DOCUMENT_DID_CLOSE = "notebookDocument/didClose"
    NOTEBOOK_DOCUMENT_DID_OPEN = "notebookDocument/didOpen"
    NOTEBOOK_DOCUMENT_DID_SAVE = "notebookDocument/didSave"
    PROGRESS = "$/progress"
    SET_TRACE = "$/setTrace"
    TEXT_DOCUMENT_DID_CHANGE = "textDocument/didChange"
    TEXT_DOCUMENT_DID_CLOSE = "textDocument/didClose"
    TEXT_DOCUMENT_DID_OPEN = "textDocument/didOpen"
    TEXT_DOCUMENT_DID_SAVE = "textDocument/didSave"
    TEXT_DOCUMENT_WILL_SAVE = "textDocument/willSave"
    WINDOW_WORK_DONE_PROGRESS_CANCEL = "window/workDoneProgress/cancel"
    WORKSPACE_DID_CHANGE_CONFIGURATION = "workspace/didChangeConfiguration"
    WORKSPACE_DID_CHANGE_WATCHED_FILES = "workspace/didChangeWatchedFiles"
    WORKSPACE_DID_CHANGE_WORKSPACE_FOLDERS = "workspace/didChangeWorkspaceFolders"
    WORKSPACE_DID_CREATE_FILES = "workspace/didCreateFiles"
    WORKSPACE_DID_DELETE_FILES = "workspace/didDeleteFiles"
    WORKSPACE_DID_RENAME_FILES = "workspace/didRenameFiles"
